close @all
logmode l

%path = @runpath
cd %path 

'Open work file 
%cty = "GNB"
wfopen GNBsoln_FTT.wf1

'Select IEA scenario
%IEA_Scen = "STEPS" ' STEPS , APS , NZE  


'Template for FTT Standalone in EViews 
%solve_start = "2024"  
%solve_end = "2050"

%techlist = "OIL SOLAR HYDRO "
for %v {%techlist}
	series CAP2INV__{%v} = (1-1/1.07^TAU__{%v})/(1-1/1.07)
	series INVpGWh__{%v} = CAPITAL_COST__{%v} * CAP2INV__{%v}
next

'Adjust model capital stock equation to remove additional investment from electricity (doesn't add to capital stock unless there are expansions)
{%cty}.drop GNBNEGDIKSTKKN GNBNYGDPPOTLKN
{%cty}.append @identity GNBNEGDIKSTKKN  = ((GNBNEGDIKSTKKN(-1)  * (1  - GNBDEPR))  + GNBNEGDIFTOTKN) - GNBNEGDIFELEKN + GNBNEGDIFELEKN_NEW
{%cty}.append @identity GNBNYGDPPOTLKN  = GNBNYGDPTFP  * (GNBLMEMPSTRL^GNBNYYWBTOTLCN_)  * (GNBNEGDIKSTKKN(-1)^(1  - GNBNYYWBTOTLCN_)) - GNBNYDELPOTLKN
{%cty}.append @identity VAR_COST = 1e-3* DEMAND_TOTAL * ( (OM_COST__OIL  + FUEL_COST__OIL  + FUEL_TAX_LEVEL__OIL  + CARBON_TAX__OIL) * SHARE__OIL  + (OM_COST__SOLAR  + FUEL_COST__SOLAR  + FUEL_TAX_LEVEL__SOLAR  + CARBON_TAX__SOLAR) * SHARE__SOLAR  + (OM_COST__HYDRO  + FUEL_COST__HYDRO  + FUEL_TAX_LEVEL__HYDRO  + CARBON_TAX__HYDRO) * SHARE__HYDRO )
{%cty}.append @identity ELECINV = INV_COST__OIL + INV_COST__SOLAR + INV_COST__HYDRO
for %v {%techlist}
	{%cty}.drop CAPITAL_COST__{%v}
	{%cty}.append @identity CAP2INV__{%v} = (1-1/1.07^TAU__{%v})/(1-1/1.07)
	{%cty}.append @identity INVpGWh__{%v} = INVpGWh__{%v}(-1)  * (1 - DLOG(ACCUMULATED_PRODUCTION_{%IEA_Scen}__{%v}) * LEARNING__{%v})
	{%cty}.append @identity CAPITAL_COST__{%v} = INVpGWh__{%v} / CAP2INV__{%v}
	{%cty}.append @identity NEWsupply__{%v} = PRODUCTION__{%v} - PRODUCTION__{%v}(-1)*(1-1/TAU__{%v})
	{%cty}.append @identity INV_COST__{%v} = 1E-3*NEWsupply__{%V}*INVpGWh__{%v}

next


smpl @all
series GNBNYDELPOTLKN = 0.0
series GNBNEGDIFELEKN = 0.0
series GNBNEGDIFELEKN_NEW = 0.0
series VAR_COST = 1e-3* DEMAND_TOTAL * ( (OM_COST__OIL  + FUEL_COST__OIL  + FUEL_TAX_LEVEL__OIL  + CARBON_TAX__OIL) * SHARE__OIL  + (OM_COST__SOLAR  + FUEL_COST__SOLAR  + FUEL_TAX_LEVEL__SOLAR  + CARBON_TAX__SOLAR) * SHARE__SOLAR  + (OM_COST__HYDRO  + FUEL_COST__HYDRO  + FUEL_TAX_LEVEL__HYDRO  + CARBON_TAX__HYDRO) * SHARE__HYDRO )
for %v {%techlist}
	series NEWsupply__{%v} = PRODUCTION__{%v} - PRODUCTION__{%v}(-1)*(1-1/TAU__{%v})
	series INV_COST__{%v} = 1e-3*NEWsupply__{%V}*CAP2INV__{%V}*CAPITAL_COST__{%v}
next
series ELECINV = INV_COST__OIL + INV_COST__SOLAR + INV_COST__HYDRO


'update model
{%cty}.update		
		
'solve for add factors 
smpl %solve_start %solve_end 
{%cty}.addassign(i,c) @stochastic  
{%cty}.addinit(v=n) @stochastic

smpl 2025 2050
GNBNEENECONSQN_A = gnbneeneconsqn_a(-1)*1.045 ' calibration of electricity demand to match 'trends' growth assumptions

'solve for solutions
smpl %solve_start %solve_end 
{%cty}.scenario "baseline"
{%cty}.solve(s=d,d=d,o=g,i=a,c=1e-6,f=t,v=t,g=n)
	
smpl %solve_start %solve_end 
%endos={%cty}.@endoglist
for %var {%endos}
	series {%var}={%var}_0
next


'----------------------------------------------------------------------------------------
' Test 1: Simple carbon tax scenario 
'----------------------------------------------------------------------------------------
{%cty}.scenario(n,a=2,i="Baseline",c) "CT30USD"
{%cty}.scenario "CT30USD"

smpl @all
series CARBON_TAX_RATE_2 = 0.0
 
smpl 2025 2025
'CARBON_TAX_RATE_2 = 21' this is the rate equivalent to limit oil lifetime
CARBON_TAX_RATE_2 = 30.0
smpl 2026 2050
CARBON_TAX_RATE_2  = CARBON_TAX_RATE_2(-1)*1.07

'Solve model to 2050 with the carbon price $20
smpl %solve_start  %solve_end 
{%cty}.override CARBON_TAX_RATE 
{%cty}.solve(s=d,d=d,o=g,i=a,c=1e-6,f=t,v=t,g=n)

'----------------------------------------------------------------------------------------
' Test 2:  Limited lifetime of oil
'---------------------------------------------------------------------------------------
{%cty}.scenario(n,a=3,i="Baseline",c) "LIMITOIL"
{%cty}.scenario "LIMITOIL"

smpl @all
series TAU__OIL_3 = TAU__OIL
smpl 2025 2050
TAU__OIL_3  =  15

smpl %solve_start  %solve_end 
{%cty}.override TAU__OIL
{%cty}.solve(s=d,d=d,o=g,i=a,c=1e-6,f=t,v=t,g=n)


'----------------------------------------------------------------------------------------
' Test 3: Equivalent carbon price to cost of shutting oil early 
'----------------------------------------------------------------------------------------
{%cty}.scenario(n,a=4,i="Baseline",c) "EQVCarbonPrice"
{%cty}.scenario "EQVCarbonPrice"

smpl @all
series CARBON_TAX_RATE_4 = 0.0 
smpl 2025 2025
CARBON_TAX_RATE_4 = 21' this is the rate equivalent to limit oil lifetime

smpl 2026 2050
CARBON_TAX_RATE_4  = CARBON_TAX_RATE_4(-1)*1.0

smpl %solve_start  %solve_end 
{%cty}.override CARBON_TAX_RATE 
{%cty}.solve(s=d,d=d,o=g,i=a,c=1e-6,f=t,v=t,g=n)

'----------------------------------------------------------------------------------------
' Test 4:  Regulation+ economic feedbacks
'---------------------------------------------------------------------------------------
{%cty}.scenario(n,a=5,i="Baseline",c) "LIMITOIL+INV"
{%cty}.scenario "LIMITOIL+INV"

smpl @all
series TAU__OIL_5 = TAU__OIL
series GNBNEGDIFELEKN_5 = 0.0 
series GNBNEGDIFELEKN_NEW_5 = 0.0
'series GNBNYDELPOTLKN_5 = 0.0

smpl 2025 2050
TAU__OIL_5  =  15
GNBNEGDIFELEKN_5 = (ELECINV_3-ELECINV_0)* @elem(GNBPANUSATLS,2020) ' million of dollar constant price convert to local currency  - investment change in electricity sector (to be subtract from capital stock formation)
GNBNEGDIFELEKN_NEW_5 =  1E-3*(PRODUCTIONTOT_3 - PRODUCTIONTOT_0)*(PRODUCTION__OIL_0*INVpGWh__OIL_0+PRODUCTION__HYDRO_0*INVpGWh__HYDRO_0+PRODUCTION__SOLAR_0*INVpGWh__SOLAR_0)/(PRODUCTION__OIL_0+ PRODUCTION__HYDRO_0+ PRODUCTION__SOLAR_0) * @elem(GNBPANUSATLS, 2020) 'add back new electricity capacity investment - to be added from capital stock formation
'GNBNYDELPOTLKN_5 =  (VAR_COST_3-VAR_COST_0) * @elem(GNBPANUSATLS, 2020)


'Solve model to 2050 with regulation and economic feedbacks
smpl %solve_start  %solve_end 
{%cty}.override TAU__OIL  GNBNEGDIFELEKN GNBNEGDIFELEKN_NEW ' GNBNYDELPOTLKN
{%cty}.solve(s=d,d=d,o=g,i=a,c=1e-6,f=t,v=t,g=n)


'----------------------------------------------------------------------------------------
' Test 7:  EQV CP Regulation+ economic feedbacks
'---------------------------------------------------------------------------------------
{%cty}.scenario(n,a=6,i="Baseline",c) "EQVCP+INV"
{%cty}.scenario "EQVCP+INV"

smpl @all
smpl @all
series CARBON_TAX_RATE_6 = 0.0 
series GNBNEGDIFELEKN_6 = 0.0 
series GNBNEGDIFELEKN_NEW_6 = 0.0
series GNBNYDELPOTLKN_6 = 0.0

smpl 2025 2050
series CARBON_TAX_RATE_6 = 21
GNBNEGDIFELEKN_6 = (ELECINV_4-ELECINV_0)* @elem(GNBPANUSATLS,2020) ' million of dollar constant price convert to local currency  - investment change in electricity sector (to be subtract from capital stock formation)
GNBNEGDIFELEKN_NEW_6 =  1E-3*(PRODUCTIONTOT_4-PRODUCTIONTOT_0)*(PRODUCTION__OIL_0*INVpGWh__OIL_0+PRODUCTION__HYDRO_0*INVpGWh__HYDRO_0+PRODUCTION__SOLAR_0*INVpGWh__SOLAR_0)/(PRODUCTION__OIL_0+ PRODUCTION__HYDRO_0+ PRODUCTION__SOLAR_0) * @elem(GNBPANUSATLS, 2020) 'add back new electricity capacity investment - to be added from capital stock formation
GNBNYDELPOTLKN_6 =  (VAR_COST_4-VAR_COST_0) * @elem(GNBPANUSATLS, 2020)


'Solve model to 2050 with regulation and economic feedbacks
smpl %solve_start  %solve_end 
{%cty}.override  CARBON_TAX_RATE GNBNYDELPOTLKN GNBNEGDIFELEKN GNBNEGDIFELEKN_NEW ' 
{%cty}.solve(s=d,d=d,o=g,i=a,c=1e-6,f=t,v=t,g=n)


'----------------------------------------------------------------------------------------
' Test 8: another 20MW solar to come online in 2025
'---------------------------------------------------------------------------------------
{%cty}.scenario(n,a=7,i="Baseline",c) "Kickstarts"
{%cty}.scenario "Kickstarts"

smpl @all
smpl @all
series SHARE_ADJ__SOLAR_7 = 0.0
series SHARE_ADJ__OIL_7 = 0.0
series LEAD__SOLAR_7 = LEAD__SOLAR

'Make the change in 2025 
smpl 2025 2025
SHARE_ADJ__SOLAR_7 =   0.1
SHARE_ADJ__OIL_7 =  -0.1
smpl 2025 2050
LEAD__SOLAR_7 = 1

'Solve model to 2050 with regulation and economic feedbacks
smpl %solve_start  %solve_end 
{%cty}.override  SHARE_ADJ__SOLAR SHARE_ADJ__OIL LEAD__SOLAR
{%cty}.solve(s=d,d=d,o=g,i=a,c=1e-6,f=t,v=t,g=n)



'----------------------------------------------------------------------------------------
' Test 9:Carbon tax with economic impacts
'---------------------------------------------------------------------------------------
{%cty}.scenario(n,a=8,i="Baseline",c) "CT+Econ"
{%cty}.scenario "CT+Econ"

smpl @all
series CARBON_TAX_RATE_8 = 0.0
series GNBNEGDIFELEKN_8 = 0.0 
series GNBNEGDIFELEKN_NEW_8 = 0.0

smpl 2025 2025
CARBON_TAX_RATE_8 = 30.0
smpl 2026 2050
CARBON_TAX_RATE_8  = CARBON_TAX_RATE_8(-1)*1.07


smpl 2025 2050
GNBNEGDIFELEKN_8 = (ELECINV_2-ELECINV_0)* @elem(GNBPANUSATLS,2020) ' million of dollar constant price convert to local currency  - investment change in electricity sector (to be subtract from capital stock formation)
GNBNEGDIFELEKN_NEW_8 =  1E-3*(PRODUCTIONTOT_2 - PRODUCTIONTOT_0)*(PRODUCTION__OIL_0*INVpGWh__OIL_0+PRODUCTION__HYDRO_0*INVpGWh__HYDRO_0+PRODUCTION__SOLAR_0*INVpGWh__SOLAR_0)/(PRODUCTION__OIL_0+ PRODUCTION__HYDRO_0+ PRODUCTION__SOLAR_0) * @elem(GNBPANUSATLS, 2020) 'add back new electricity capacity investment - to be added from capital stock formation


'Solve model to 2050 with regulation and economic feedbacks
smpl %solve_start  %solve_end 
{%cty}.override CARBON_TAX_RATE GNBNEGDIFELEKN GNBNEGDIFELEKN_NEW 
{%cty}.solve(s=d,d=d,o=g,i=a,c=1e-6,f=t,v=t,g=n)



'----------------------------------------------------------------------------------------
' Test 10: Solar kick starts with economic impacts
'---------------------------------------------------------------------------------------
{%cty}.scenario(n,a=9,i="Baseline",c) "Solar+Econ"
{%cty}.scenario "Solar+Econ"

smpl @all
series SHARE_ADJ__SOLAR_9 = 0.0
series SHARE_ADJ__OIL_9 = 0.0
series LEAD__SOLAR_9 = LEAD__SOLAR
series GNBNEGDIFELEKN_9 = 0.0 
series GNBNEGDIFELEKN_NEW_9 = 0.0

'Make the share adjustment change in 2025 
smpl 2025 2025
SHARE_ADJ__SOLAR_9 =   0.1
SHARE_ADJ__OIL_9 =  -0.1

smpl 2025 2050
LEAD__SOLAR_9 = 1
GNBNEGDIFELEKN_9 = (ELECINV_7-ELECINV_0)* @elem(GNBPANUSATLS,2020) ' million of dollar constant price convert to local currency  - investment change in electricity sector (to be subtract from capital stock formation)
GNBNEGDIFELEKN_NEW_9 =  1E-3*(PRODUCTIONTOT_7 - PRODUCTIONTOT_0)*(PRODUCTION__OIL_0*INVpGWh__OIL_0+PRODUCTION__HYDRO_0*INVpGWh__HYDRO_0+PRODUCTION__SOLAR_0*INVpGWh__SOLAR_0)/(PRODUCTION__OIL_0+ PRODUCTION__HYDRO_0+ PRODUCTION__SOLAR_0) * @elem(GNBPANUSATLS, 2020) 'add back new electricity capacity investment - to be added from capital stock formation


'Solve model to 2050 with regulation and economic feedbacks
smpl %solve_start  %solve_end 
{%cty}.override   SHARE_ADJ__SOLAR SHARE_ADJ__OIL LEAD__SOLAR GNBNEGDIFELEKN GNBNEGDIFELEKN_NEW 
{%cty}.solve(s=d,d=d,o=g,i=a,c=1e-6,f=t,v=t,g=n)


'------------------------------------------------------------------------------------------------------------
'Plot results
smpl 2025 2050
'---------------------------------------------------------
'Baseline - FIGURE 5 in the paper
delete(noerr) _BAU 
graph _BAU  DEMAND_TOTAL_0 CO2ELETOT_0*0.001
'add series labels
_BAU.name(1) Electricity Demand (Gwh)
_BAU.name(2) Power sector CO2 emissions (ktCO2)


'add title
_BAU.addtext(.71,-0.7,font(+b,16)) Baseline electricity demand and CO2 emissions from the power sector in GNB 
_BAU.axis(l) range(minmax)
_BAU.datelabel format("YYYY")
_BAU.legend columns(2)
show _BAU

'---------------------------------------------------------
'PG Share baseline - FIGURE 5 in the paper
smpl 2025 2050
delete(noerr) _ShareBAU
graph _ShareBAU SHARE__SOLAR_0 SHARE__OIL_0  SHARE__HYDRO_0

'add series labels
_ShareBAU.area(s)
_ShareBAU.name(1) Solar
_ShareBAU.name(2) Oil
_ShareBAU.name(3) Hydro

_sharebau.setelem(1) fillcolor(@rgb(255,255,128))
_sharebau.setelem(2) fillcolor(@rgb(192,192,192))
_sharebau.setelem(3) fillcolor(@rgb(0,171,255))
_sharebau.axis(l) units(p) format(suffix="%")

'add title
_ShareBAU.addtext(.71,-0.7,font(+b,16)) GNB power generation mix in the baseline
_ShareBAU.axis(l) range(0,1)
_ShareBAU.datelabel format("YYYY")

show _ShareBAU

'---------------------------------------------------------
smpl 2020 2050
'Carbon tax scenario - FIGURE 6 in the paper
delete(noerr) _CT
graph _CT ((DEMAND_TOTAL_2/DEMAND_TOTAL_0)-1)*100 ((CO2ELETOT_2/CO2ELETOT_0)-1)*100
'add series labels
_CT.name(1) Electricity Demand 
_CT.name(2) Power sector CO2 emissions 


'add title
_CT.addtext(.71,-0.7,font(+b,12)) Carbon tax scenario electricity demand and CO2 emissions from the power sector in GNB (% differences from baseline)
_CT.axis(l) range(minmax)
_CT.datelabel format("YYYY")
_CT.legend columns(2)
show _CT


'---------------------------------------------------------
'PG Share CT - FIGURE 6 in the paper
smpl 2025 2050
delete(noerr) _ShareCT
graph _ShareCT SHARE__SOLAR_2 SHARE__OIL_2  SHARE__HYDRO_2

'add series labels
_ShareCT.area(s)
_ShareCT.name(1) Solar
_ShareCT.name(2) Oil
_ShareCT.name(3) Hydro

_ShareCT.setelem(1) fillcolor(@rgb(255,255,128))
_ShareCT.setelem(2) fillcolor(@rgb(192,192,192))
_ShareCT.setelem(3) fillcolor(@rgb(0,171,255))
_ShareCT.axis(l) units(p) format(suffix="%")

'add title
_ShareCT.addtext(.71,-0.7,font(+b,16)) GNB power generation mix in the carbon tax scenario
_ShareCT.axis(l) range(0,1)
_ShareCT.datelabel format("YYYY")

show _ShareCT


'---------------------------------------------------------
smpl 2020 2050
'Kick start scenario - FIGURE 7 in the paper
delete(noerr) _KS
graph _KS ((DEMAND_TOTAL_7/DEMAND_TOTAL_0)-1)*100 ((CO2ELETOT_7/CO2ELETOT_0)-1)*100
'add series labels
_KS.name(1) Electricity Demand 
_KS.name(2) Power sector CO2 emissions 


'add title
_KS.addtext(.71,-0.7,font(+b,12)) Kick-start solar scenario electricity demand and CO2 emissions from the power sector in GNB (% differences from baseline)
_KS.axis(l) range(minmax)
_KS.datelabel format("YYYY")
_KS.legend columns(2)
show _KS

'---------------------------------------------------------
'PG Share KS - FIGURE 7 in the paper
smpl 2025 2050
delete(noerr) _ShareKS
graph _ShareKS SHARE__SOLAR_7 SHARE__OIL_7  SHARE__HYDRO_7

'add series labels
_ShareKS.area(s)
_ShareKS.name(1) Solar
_ShareKS.name(2) Oil
_ShareKS.name(3) Hydro

_ShareKS.setelem(1) fillcolor(@rgb(255,255,128))
_ShareKS.setelem(2) fillcolor(@rgb(192,192,192))
_ShareKS.setelem(3) fillcolor(@rgb(0,171,255))
_ShareKS.axis(l) units(p) format(suffix="%")

'add title
_ShareKS.addtext(.71,-0.7,font(+b,16)) GNB power generation mix in the kick-start solar scenario
_ShareKS.axis(l) range(0,1)
_ShareKS.datelabel format("YYYY")

show _ShareKS


'---------------------------------------------------------
smpl 2020 2050
'Oil regulation scenario - FIGURE 8 in the paper
delete(noerr) _OIL
graph _OIL ((DEMAND_TOTAL_3/DEMAND_TOTAL_0)-1)*100 ((CO2ELETOT_3/CO2ELETOT_0)-1)*100
'add series labels
_OIL.name(1) Electricity Demand 
_OIL.name(2) Power sector CO2 emissions 


'add title
_OIL.addtext(.71,-0.7,font(+b,12)) Oil regulation scenario electricity demand and CO2 emissions from the power sector in GNB (% differences from baseline)
_OIL.axis(l) range(minmax)
_OIL.datelabel format("YYYY")
_OIL.legend columns(2)
show _OIL

'---------------------------------------------------------
'PG Share Oil regulation -  FIGURE 8 in the paper
smpl 2025 2050
delete(noerr) _ShareOIL
graph _ShareOIL SHARE__SOLAR_3 SHARE__OIL_3  SHARE__HYDRO_3

'add series labels
_ShareOIL.area(s)
_ShareOIL.name(1) Solar
_ShareOIL.name(2) Oil
_ShareOIL.name(3) Hydro

_ShareOIL.setelem(1) fillcolor(@rgb(255,255,128))
_ShareOIL.setelem(2) fillcolor(@rgb(192,192,192))
_ShareOIL.setelem(3) fillcolor(@rgb(0,171,255))
_ShareOIL.axis(l) units(p) format(suffix="%")

'add title
_ShareOIL.addtext(.71,-0.7,font(+b,16)) GNB power generation mix in theoil regulation scenario
_ShareOIL.axis(l) range(0,1)
_ShareOIL.datelabel format("YYYY")

show _ShareOIL

'Table with results from carbon tax with econ feedback, solar start with econ feedback, oil regulation with econ feedback  TABLE 4 in the paper
smpl 2025 2050
group table  ((GNBNYGDPMKTPKN_8/GNBNYGDPMKTPKN_0)-1)*100  ((DEMAND_TOTAL_2/DEMAND_TOTAL_0)-1)*100 ((COST_AVERAGE_8/COST_AVERAGE_0)-1)*100 ((GNBGGDBTTOTLCN_8/GNBNYGDPMKTPCN_0)-(GNBGGDBTTOTLCN_0/GNBNYGDPMKTPCN_0))*100  ((GNBNYGDPMKTPKN_9/GNBNYGDPMKTPKN_0)-1)*100  ((DEMAND_TOTAL_7/DEMAND_TOTAL_0)-1)*100  ((COST_AVERAGE_9/COST_AVERAGE_0)-1)*100 ((GNBGGDBTTOTLCN_9/GNBNYGDPMKTPCN_0)-(GNBGGDBTTOTLCN_0/GNBNYGDPMKTPCN_0))*100 ((GNBNYGDPMKTPKN_5/GNBNYGDPMKTPKN_0)-1)*100  ((DEMAND_TOTAL_3/DEMAND_TOTAL_0)-1)*100 ((COST_AVERAGE_5/COST_AVERAGE_0)-1)*100 ((GNBGGDBTTOTLCN_5/GNBNYGDPMKTPCN_0)-(GNBGGDBTTOTLCN_0/GNBNYGDPMKTPCN_0))*100 



freeze(mode = overwrite,tableout) table.sheet(t)
tableout.deletecol(c) 4
tableout.deletecol(d) 9
tableout.deletecol(e) 9

tableout.insertrow(3) 1
tableout.insertrow(8) 1
tableout.insertrow(13) 1

'variable headings
tableout(3,1) = "Carbon tax"
tableout.setfont(a3:a3) +b
tableout(4,1) = "GDP Impacts"
tableout(5,1) = "Changes in electricity supply"
tableout(6,1) = "Electricity price"
tableout(7,1) = "Debt share of GDP (absolute differences)"

tableout(8,1) = "Solar kick-start policies"
tableout.setfont(a8:a8) +b
tableout(9,1) = "GDP Impacts"
tableout(10,1) = "Changes in electricity supply"
tableout(11,1) = "Electricity price"
tableout(12,1) = "Debt share of GDP (absolute differences)"

tableout(13,1) = "Solar kick-start policies"
tableout.setfont(a13:a13) +b
tableout(14,1) = "GDP Impacts"
tableout(15,1) = "Changes in electricity supply"
tableout(16,1) = "Electricity price"
tableout(17,1) = "Debt share of GDP (absolute differences)"

tableout.setformat(b4:g17) f.1


show tableout


